/**********************************************************************

  Audacity: A Digital Audio Editor

  ModuleConstants.cpp

  Paul Licameli

**********************************************************************/

#include "ModuleConstants.h"

// We want Audacity with a capital 'A'
const std::wstring AppName = L"Audacity";
